@@ -16,7 +16,7 @@ use Carp;
 use HiPi::Device::GPIO::Pin;
 use Time::HiRes;
 
-our $VERSION ='0.64';
+our $VERSION ='0.65';
 
 my $sysroot = '/sys/class/gpio';
 
@@ -49,11 +49,16 @@ sub new {
 
 sub get_pin {
     my( $self, $pinid ) = @_;
-    HiPi::Device::GPIO::Pin->_open( pinid => $pinid );
+    my $pinroot = qq(${sysroot}/gpio${pinid});
+    if( !-d $pinroot ) {
+        return $self->export_pin( $pinid );
+    } else {
+        return HiPi::Device::GPIO::Pin->_open( pinid => $pinid );
+    }
 }
 
 sub export_pin {
-    my( $self, $pinno, $gname ) = @_;
+    my( $self, $pinno ) = @_;
     my $pinroot = qq(${sysroot}/gpio${pinno});
     # export the pin
     
@@ -77,7 +82,7 @@ sub export_pin {
         }
     }
     
-    $self->get_pin( $pinno );
+    return HiPi::Device::GPIO::Pin->_open( pinid => $pinno );
 }
 
 sub unexport_pin {
