@@ -17,7 +17,6 @@ use parent qw( HiPi::Device );
 use HiPi qw( :i2c :rpi );
 use HiPi::RaspberryPi;
 use IO::File;
-use Fcntl;
 use XSLoader;
 use Carp;
 use Time::HiRes qw( usleep );
@@ -28,7 +27,7 @@ use constant {
     I2C_BCM2835 => 2,
 };
 
-our $VERSION ='0.64';
+our $VERSION ='0.65';
 
 __PACKAGE__->create_accessors( qw ( fh fno address busmode readmode ) );
 
@@ -42,7 +41,7 @@ my $baudrate_param_path = '/sys/module/i2c_bcm2708/parameters/baudrate';
 sub get_required_module_options {
     my $moduleoptions = [
         [ qw( i2c_bcm2708 i2c_dev ) ], # older i2c modules
-        [ qw( i2c_bcm2385 i2c_dev ) ],         # recent i2c modules
+        [ qw( i2c_bcm2385 i2c_dev ) ], # recent i2c modules
     ];
     return $moduleoptions;
 }
@@ -60,18 +59,28 @@ sub get_device_list {
 
 sub get_baudrate {
     my ($class) = @_;
-    my $baudrate = qx(/bin/cat $baudrate_param_path);
-    if($?) {
-        carp q(Unable to determine baudrate);
-        return 0;
+    if ( $modvers == I2C_BCM2835 ) {
+        my $baudrate = qx(xxd -ps /sys/class/i2c-adapter/i2c-1/of_node/clock-frequency);
+        chomp $baudrate;
+        return hex($baudrate);
+    } else {
+        my $baudrate = qx(/bin/cat $baudrate_param_path);
+        if($?) {
+            carp q(Unable to determine baudrate);
+            return 0;
+        }
+        chomp($baudrate);
+        return $baudrate;
     }
-    chomp($baudrate);
-    return $baudrate;
 }
 
+sub get_driver {
+    return ( $modvers == I2C_BCM2835 ) ? 'i2c_bcm2835' : 'i2c_bcm2708';
+}
 
 sub get_combined {
     my ($class) = @_;
+    return 'Y' if $modvers == I2C_BCM2835;
     my $combined = qx(/bin/cat $combined_param_path);
     if($?) {
         carp q(Unable to determine combined setting);
@@ -86,6 +95,7 @@ sub set_combined {
     $newval //= 'N';
     $newval = uc($newval);
     croak('Usage HiPi::Device::I2C->set_combined( "Y|N" )') unless ( $newval =~ /^Y|N$/ );
+    return 'Y' if $modvers == I2C_BCM2835;
     qx(/bin/echo $newval > $combined_param_path);
     return $newval;
 }
@@ -159,6 +169,7 @@ sub scan_bus {
     $end //= 0x77;
     $start = 0x03 if $start < 0x03;
     $end = 0x77 if $end > 0x77;
+    $end = $start if $end < $start;
     my @results = i2c_scan_bus($self->fno, $mode, $start, $end);
     
     # need to reset the ioctl address 
@@ -167,6 +178,15 @@ sub scan_bus {
     return @results;
 }
 
+sub check_address {
+    my($self, $checkaddress) = @_;
+    $checkaddress //= $self->address;
+    return 0 unless $checkaddress;
+    my @result = $self->scan_bus(I2C_SCANMODE_AUTO, $checkaddress, $checkaddress );
+    return 0 unless @result;
+    return (  $result[0] == $checkaddress ) ? 1 : 0;
+}
+
 #-------------------------------------------
 # Methods that honour busmode (smbus or i2c)
 #-------------------------------------------
