@@ -17,14 +17,24 @@ use XSLoader;
 use Carp;
 use HiPi qw( :rpi );
 
-our $VERSION ='0.64';
+our $VERSION ='0.65';
 
-__PACKAGE__->create_accessors( qw ( ok sysroot ) );
+__PACKAGE__->create_accessors( );
 
 XSLoader::load('HiPi::GPIO', $VERSION) if HiPi::is_raspberry_pi();
 
 my $xsok = ( HiPi::is_raspberry_pi() ) ? xs_initialise_gpio_block() : 0;
-END { xs_release_gpio_block() if HiPi::is_raspberry_pi(); }
+END { xs_release_gpio_block() if HiPi::is_raspberry_pi(); };
+
+use constant {
+    GPEDS0   => 16,
+    GPREN0   => 19,
+    GPFEN0   => 22,
+    GPHEN0   => 25,
+    GPLEN0   => 28,
+    GPAREN0  => 31,
+    GPAFEN0  => 34,
+};
 
 my @_alt_function_names = (
     [qw( I2C0_SDA      SA5          ALT2   ALT3   ALT4        ALT5 ) ], # GPIO 0
@@ -75,56 +85,56 @@ sub error_report {
     carp qq($error);
 }
 
+sub ok { return $xsok; }
+
 sub new {
     my ($class, %userparams) = @_;
     
-    my %params = (
-        sysroot => '/sys/class/gpio',
-    );
+    my %params = ( );
     
     foreach my $key( sort keys( %params ) ) {
         $params{$key} = $userparams{$key} if exists($userparams{$key});
     }
          
     my $self = $class->SUPER::new(%params);
-    $self->ok($xsok);
+   
     return $self;
 }
 
 sub get_pin {
-    my( $self, $pinid ) = @_;
+    my( $class, $pinid ) = @_;
     require HiPi::GPIO::Pin;
     HiPi::GPIO::Pin->_open( pinid => $pinid );
 }
 
 sub pin_write {
-    my($self, $gpio, $level) = @_;
+    my($class, $gpio, $level) = @_;
     return xs_gpio_write( $gpio, $level );
 }
 
 sub pin_read {
-    my($self, $gpio) = @_;
+    my($class, $gpio) = @_;
     return xs_gpio_read( $gpio );
 }
 
 sub set_pin_mode {
-    my($self, $gpio, $mode) = @_;
+    my($class, $gpio, $mode) = @_;
     return xs_gpio_set_mode( $gpio, $mode );
 }
 
 sub get_pin_mode {
-    my($self, $gpio ) = @_;
+    my($class, $gpio ) = @_;
     return xs_gpio_get_mode( $gpio );
 }
 
 sub set_pin_pud {
-    my($self, $gpio , $pud ) = @_;
+    my($class, $gpio , $pud ) = @_;
     return xs_gpio_set_pud( $gpio, $pud);
 }
 
 sub get_pin_function {
-    my($self, $gpio) = @_;
-    my $mode = $self->get_pin_mode( $gpio );
+    my($class, $gpio) = @_;
+    my $mode = $class->get_pin_mode( $gpio );
     my $funcname = 'UNKNOWN';
     my $altnum = undef;
     if( $mode == -1 ) {
@@ -158,6 +168,82 @@ sub get_pin_function {
     return ( wantarray ) ? ( $funcname, $altnum ) : $funcname;
 }
 
+sub get_pin_edge_detect {
+    my( $self, $gpio ) = @_;
+    return xs_gpio_read_edge_detect( $gpio );
+}
+
+sub clear_pin_edge_detect {
+    my( $self, $gpio ) = @_;
+    return xs_gpio_clear_edge_detect( $gpio );
+}
+
+sub set_rising_edge_detect {
+    my($class, $gpio, $val) = @_;
+    $val //= 0;
+    return xs_gpio_set_edge_detect( $gpio, GPREN0(), $val);
+}
+
+sub get_rising_edge_detect {
+    my($class, $gpio) = @_;
+    return xs_gpio_get_edge_detect( $gpio, GPREN0());
+}
+
+sub set_falling_edge_detect {
+    my($class, $gpio, $val) = @_;
+    $val //= 0;
+    return xs_gpio_set_edge_detect( $gpio, GPFEN0(), $val);
+}
+
+sub get_falling_edge_detect {
+    my($class, $gpio) = @_;
+    return xs_gpio_get_edge_detect( $gpio, GPFEN0());
+}
+
+sub set_high_edge_detect {
+    my($class, $gpio, $val) = @_;
+    $val //= 0;
+    return xs_gpio_set_edge_detect( $gpio, GPHEN0(), $val);
+}
+
+sub get_high_edge_detect {
+    my($class, $gpio) = @_;
+    return xs_gpio_get_edge_detect( $gpio, GPHEN0());
+}
+
+sub set_low_edge_detect {
+    my($class, $gpio, $val) = @_;
+    $val //= 0;
+    return xs_gpio_set_edge_detect( $gpio, GPLEN0(), $val);
+}
+
+sub get_low_edge_detect {
+    my($class, $gpio) = @_;
+    return xs_gpio_get_edge_detect( $gpio, GPLEN0());
+}
+
+sub set_async_rising_edge_detect {
+    my($class, $gpio, $val) = @_;
+    $val //= 0;
+    return xs_gpio_set_edge_detect( $gpio, GPAREN0(), $val);
+}
+
+sub get_async_rising_edge_detect {
+    my($class, $gpio) = @_;
+    return xs_gpio_get_edge_detect( $gpio, GPAREN0());
+}
+
+sub set_async_falling_edge_detect {
+    my($class, $gpio, $val) = @_;
+    $val //= 0;
+    return xs_gpio_set_edge_detect( $gpio, GPAFEN0(), $val);
+}
+
+sub get_async_falling_edge_detect {
+    my($class, $gpio) = @_;
+    return xs_gpio_get_edge_detect( $gpio, GPAFEN0());
+}
+
 # Aliases
 
 *HiPi::GPIO::get_pin_level = \&pin_read;
