@@ -17,7 +17,7 @@ use Carp;
 use HiPi qw( :rpi :lcd );
 use HiPi::RaspberryPi;
 
-our $VERSION ='0.64';
+our $VERSION ='0.65';
 
 __PACKAGE__->create_accessors( qw( devicetype address devicename backend ) );
 
@@ -76,6 +76,16 @@ sub new {
             
             $params{device} = HiPi::Device::SerialPort->new(%devparams);
             
+        } elsif( $params{backend} eq 'bcm2835' ) {
+            require HiPi::BCM2835::I2C;
+            $params{devicename} = $params{i2c_devicename} unless $params{devicename};
+	        $params{address}    = $params{i2c_address} unless defined($params{address});
+            
+            $params{device} = HiPi::BCM2835::I2C->new(
+                address    => $params{address},
+                peripheral => ( $params{devicename} eq '/dev/i2c-0' ) ? HiPi::BCM2835::I2C::BB_I2C_PERI_0() : HiPi::BCM2835::I2C::BB_I2C_PERI_1(),
+            );
+            
         } elsif( $params{backend} =~ /^(i2c|smbus)$/i ) {
             
             $params{devicename} = $params{i2c_devicename} unless $params{devicename};
