@@ -15,7 +15,7 @@ use warnings;
 use parent qw( HiPi::Class );
 use HiPi qw( :rpi );
 
-our $VERSION ='0.64';
+our $VERSION ='0.65';
 
 __PACKAGE__->create_ro_accessors( qw( pinid ) );
 
@@ -45,14 +45,30 @@ sub mode {
 }
 
 sub interrupt {
-    my($self, $newval) = @_;
-    if(defined($newval)) {
-        return $self->_do_setinterrupt($newval);
+    my($self, $newedge) = @_;
+    if(defined($newedge)) {
+        $newedge ||= RPI_INT_NONE;
+        $newedge = RPI_INT_FALL if $newedge eq 'falling';
+        $newedge = RPI_INT_RISE if $newedge eq 'rising';
+        $newedge = RPI_INT_BOTH if $newedge eq 'both';
+        $newedge = RPI_INT_NONE if $newedge eq 'none';
+        return $self->_do_setinterrupt($newedge);
     } else {
         return $self->_do_getinterrupt();
     }
 }
 
+sub get_edge_detect {
+    my($self) = @_;
+    $self->_do_get_edge_detect;
+}
+
+
+sub clear_edge_detect {
+    my($self) = @_;
+    $self->_do_clear_edge_detect;
+}
+
 sub set_pud {
     my($self, $newval) = @_;
     my $rval;
